==> haskell-persistent-qq-2.12.0.6-317-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-GMZn7WN9ojuLJfVjghqRrm
key:                  persistent-qq-2.12.0.6-GMZn7WN9ojuLJfVjghqRrm
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  3e218f30c91e30649735e81e9369b2cd
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-GMZn7WN9ojuLJfVjghqRrm
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-3Jf15RtzGPm7MtbwPnZuN2
    mtl-2.2.2 persistent-2.14.5.1-7Qihlg8XAdWKP5Yrt0RRps
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.6-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-4JlFoUHOeSrAq7DFNeA5Fg
key:                  persistent-qq-2.12.0.6-4JlFoUHOeSrAq7DFNeA5Fg
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  e8f50615b4c4c5663acf910c9a7a0f58
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-4JlFoUHOeSrAq7DFNeA5Fg
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-3Jf15RtzGPm7MtbwPnZuN2
    mtl-2.2.2 persistent-2.14.5.1-7PCIqFKnw4YCJ1m7ql6nWw
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
